@@ -23,9 +23,6 @@ arma::mat colSortC(arma::mat X) {
   return Y;
 }
 
-/*** R
-A <- matrix(rnorm(15), 5, 3)
-B <- colSortC(A)
-*/
+
 
 
